==> nextcloud-12.0.3-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/ru.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Галерея",
    "There was a problem reading files from this album" : "Проблема при чтении файлов из этого альбома",
    "Aborting preview. Could not find the file" : "Предпросмотр отменен. Не удалось найти файл",
    "Could not move \"{file}\", target exists" : "Невозможно переместить \"{file}\", он уже существует в каталоге назначения",
    "Could not move \"{file}\"" : "Невозможно переместить \"{file}\"",
    "No compatible server found at {remote}" : "Совместимый сервер на {remote} не найден",
    "Invalid server url" : "Неверный URL-адрес сервера",
    "Could not load the description" : "Не удалось загрузить описание",
    "Could not load the description: " : "Не удалось загрузить описание:",
    "Copyright" : "Авторские права защищены",
    "Could not load the copyright notice: " : "Не удалось загрузить уведомление об авторских правах:",
    "Copyright notice" : "Уведомление об авторских правах",
    "Link to copyright document" : "Ссылка на документ об авторских правах",
    "This application may not work properly on your browser." : "Это приложение может некорректно работать в Вашем браузере.",
    "For an improved experience, please install one of the following alternatives" : "Для наилучшего результата, пожалуйста, установите одну из следующих альтернатив",
    "Your browser is not supported!" : "Ваш браузер не поддерживается!",
    "please install one of the following alternatives" : "пожалуйста, установите одну из следующих альтернатив",
    "Album cannot be shown" : "Этот альбом не может быть отображен",
    "No media files found" : "Медиафайлы не найдены",
    "Upload pictures in the Files app to display them here" : "Загрузите изображения в приложении «Файлы» для их просмотра",
    "Upload new files via drag and drop or by using the [+] button above" : "Перетащите файлы или используйте кнопку [ + ] выше",
    "Configuration error" : "Ошибка конфигурации",
    "New" : "Новый",
    "Hide Album" : "Скрыть альбом",
    "Could not hide album" : "Не удалось скрыть альбом",
    "Error loading slideshow template" : "Ошибка при загрузке шаблона слайд-шоу",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Ошибка!</strong> Не удалось создать предпросмотр файлы. <br>Пожалуйста переходите к следующему слайду, пока мы удалим это изображение из слайд-шоу",
    "Next" : "Следующий",
    "Play" : "Проиграть",
    "Pause" : "Пауза",
    "Previous" : "Предыдущий",
    "Close" : "Закрыть",
    "Download" : "Скачать",
    "Toggle background" : "Переключить фон",
    "Delete" : "Удалить",
    "Could not create file \"{file}\" because it already exists" : "Невозможно создать файл \"{file}\" потому что уже имеется",
    "Could not create file \"{file}\"" : "Невозможно создать файл \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" это неправильное имя файла.",
    "File name cannot be empty." : "Имя файла не может быть пустым.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" - недопустимый тип файла",
    "Upload" : "Загрузить",
    "Error" : "Ошибка",
    "Error while sharing" : "При попытке поделиться произошла ошибка",
    "Error while unsharing" : "При закрытии доступа произошла ошибка",
    "Error while changing permissions" : "При изменении прав доступа произошла ошибка",
    "Shared with you and the group {group} by {owner}" : "{owner} поделился с вами и группой {group} ",
    "Shared with you by {owner}" : "С вами поделился {owner} ",
    "Share with users or groups …" : "Поделиться с пользователями или группами ...",
    "Share with users, groups or remote users …" : "Поделиться с пользователями, группами или удаленными пользователями ...",
    "Share" : "Открыть доступ",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Предоставить доступ людям на других серверах, используя их идентификатор в федерации облачных хранилищ username@example.com/cloud",
    "Share link" : "Поделиться ссылкой",
    "The public link will expire no later than {days} days after it is created" : "Срок действия публичной ссылки истекает не позже чем через {days} дней после её создания",
    "Link" : "Ссылка",
    "Password protect" : "Защитить паролем",
    "Password" : "Пароль",
    "Choose a password for the public link" : "Укажите пароль для публичной ссылки",
    "Allow editing" : "Разрешить редактирование",
    "Email link to person" : "Отправить ссылку по электронной почте",
    "Send" : "Отправить",
    "Set expiration date" : "Установить срок действия",
    "Expiration" : "Срок действия",
    "Expiration date" : "Дата окончания",
    "This list is maybe truncated - please refine your search term to see more results." : "Этот список может быть показан не полностью - уточните запрос что бы просмотреть больше результатов.",
    "No users or groups found for {search}" : "Не найдено пользователей или групп по запросу {search}",
    "No users found for {search}" : "Не найдено пользователей по запросу {search}",
    "An error occured. Please try again" : "Произошла ошибка. Попробуйте ещё раз",
    "Adding user..." : "Добавляем пользователя...",
    "group" : "группа",
    "remote" : "удаленный",
    "Resharing is not allowed" : "Повторное открытие доступа запрещено",
    "Error while retrieving shares" : "Ошибка получения списка общих ресурсов",
    "Unshare" : "Закрыть доступ",
    "notify by email" : "уведомить по почте",
    "can share" : "можно поделиться",
    "can edit" : "можно редактировать",
    "access control" : "контроль доступа",
    "create" : "создать",
    "change" : "изменить",
    "delete" : "удалить",
    "Password protected" : "Защищено паролем",
    "Error unsetting expiration date" : "Ошибка при отмене срока доступа",
    "Error setting expiration date" : "Ошибка при установке срока доступа",
    "Sending ..." : "Отправляется ...",
    "Email sent" : "Письмо отправлено",
    "Warning" : "Предупреждение",
    "This share is password-protected" : "Общий ресурс защищен паролем",
    "The password is wrong. Try again." : "Неверный пароль. Попробуйте еще раз.",
    "Sort by date" : "Сортировать по дате",
    "Sort by name" : "Сортировать по имени",
    "Cancel upload" : "Отменить загрузку",
    "Album information" : "Информация об альбоме",
    "File list" : "Список файлов",
    "Sorry, this file could not be found." : "К сожалению, файл не найден.",
    "Reasons might be:" : "Причиной может быть:",
    "the wrong file ID was provided" : "предоставлен ошибочный ID файла",
    "the file was removed" : "файл был удален",
    "the file is corrupt" : "файл поврежден",
    "the encryption key is missing" : "отсутствует ключ шифрования",
    "Here is the error message returned by the server: " : "Вот сообщение об ошибке, возвращенное сервером:",
    "For more information, please contact your friendly Nextcloud administrator." : "Для получения более подробной информации, пожалуйста, обратитесь к администратору вашего Nextcloud.",
    "Sorry, but the server could not fulfill your request." : "К сожалению, сервер не смог выполнить Ваш запрос.",
    "Possible reasons for the problem:" : "Возможные причины проблемы:",
    "a conflicting app was installed" : "было установлено конфликтующее приложение",
    "a required component is missing or was disconnected" : "необходимый компонент отсутствует или был отключен",
    "the filesystem is not readable" : "файловая система нечитаема",
    "Sorry, this link doesn't seem to work anymore." : "К сожалению, эта ссылка более недоступна.",
    "the item was removed" : "элемент был удалён",
    "the link has expired" : "срок действия ссылки истек",
    "sharing is disabled" : "общий доступ отключён",
    "For more information, please ask the person who has sent you this link." : "Для получения более подробной информации, пожалуйста, обратитесь к человеку, который послал вам эту ссылку.",
    "Add to your Nextcloud" : "Добавить в ваш Nextcloud",
    "Picture view" : "Просмотр изображения",
    "Gallery view" : "Галерея"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/ru.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Галерея",
    "There was a problem reading files from this album" : "Проблема при чтении файлов из этого альбома",
    "Aborting preview. Could not find the file" : "Предпросмотр отменен. Не удалось найти файл",
    "Could not move \"{file}\", target exists" : "Невозможно переместить «{file}», файл уже существует в каталоге назначения",
    "Could not move \"{file}\"" : "Невозможно переместить «{file}»",
    "No compatible server found at {remote}" : "Совместимый сервер на {remote} не найден",
    "Invalid server url" : "Неверный URL-адрес сервера",
    "Could not load the description" : "Не удалось загрузить описание",
    "Could not load the description: " : "Не удалось загрузить описание:",
    "Copyright" : "Авторские права защищены",
    "Could not load the copyright notice: " : "Не удалось загрузить уведомление об авторских правах:",
    "Copyright notice" : "Уведомление об авторских правах",
    "Link to copyright document" : "Ссылка на документ об авторских правах",
    "This application may not work properly on your browser." : "Это приложение может некорректно работать в вашем браузере.",
    "For an improved experience, please install one of the following alternatives" : "Для наилучшего результата, пожалуйста, установите одну из следующих альтернатив",
    "Your browser is not supported!" : "Ваш браузер не поддерживается!",
    "please install one of the following alternatives" : "установите одну из следующих альтернатив",
    "Album cannot be shown" : "Этот альбом не может быть отображен",
    "No media files found" : "Медиафайлы не найдены",
    "Upload pictures in the Files app to display them here" : "Загрузите изображения в приложении «Файлы» для их просмотра",
    "Upload new files via drag and drop or by using the [+] button above" : "Перетащите файлы или используйте кнопку [ + ] выше",
    "Configuration error" : "Ошибка конфигурации",
    "New" : "Новый",
    "Hide Album" : "Скрыть альбом",
    "Could not hide album" : "Не удалось скрыть альбом",
    "Error loading slideshow template" : "Ошибка при загрузке шаблона слайд-шоу",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Ошибка!</strong> Не удалось создать предварительный просмотр этого файла.<br>Это изображение будет исключено из показа слайдов, перейдите к следующему",
    "Next" : "Следующий",
    "Play" : "Проиграть",
    "Pause" : "Пауза",
    "Previous" : "Предыдущий",
    "Close" : "Закрыть",
    "Download" : "Скачать",
    "Toggle background" : "Переключить фон",
    "Delete" : "Удалить",
    "Share" : "Открыть доступ",
    "Could not create file \"{file}\" because it already exists" : "Невозможно создать файл «{file}», он уже существует",
    "Could not create file \"{file}\"" : "Невозможно создать файл «{file}»",
    "\"{name}\" is an invalid file name." : "«{name}» — недопустимое имя файла.",
    "File name cannot be empty." : "Имя файла не может быть пустым.",
    "\"{name}\" is not an allowed filetype" : "«{name}» - недопустимый тип файла.",
    "Upload" : "Передать на сервер",
    "Error" : "Ошибка",
    "Error while sharing" : "При открытии общего доступа произошла ошибка",
    "Error while unsharing" : "При закрытии доступа произошла ошибка",
    "Error while changing permissions" : "При изменении прав доступа произошла ошибка",
    "Shared with you and the group {group} by {owner}" : "{owner} поделился с вами и группой {group} ",
    "Shared with you by {owner}" : "С вами поделился {owner} ",
    "Share with users or groups …" : "Поделиться с пользователями или группами ...",
    "Share with users, groups or remote users …" : "Поделиться с пользователями, группами или удаленными пользователями ...",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Предоставить доступ людям на других серверах, используя их идентификатор в федерации облачных хранилищ username@example.com/cloud",
    "Share link" : "Поделиться ссылкой",
    "The public link will expire no later than {days} days after it is created" : "Срок действия публичной ссылки истекает не позже чем через {days} дней после её создания",
    "Link" : "Ссылка",
    "Password protect" : "Защитить паролем",
    "Password" : "Пароль",
    "Choose a password for the public link" : "Укажите пароль для публичной ссылки",
    "Allow editing" : "Разрешить редактирование",
    "Email link to person" : "Отправить ссылку по электронной почте",
    "Send" : "Отправить",
    "Set expiration date" : "Установить срок действия",
    "Expiration" : "Срок действия",
    "Expiration date" : "Дата окончания",
    "This list is maybe truncated - please refine your search term to see more results." : "Этот список может быть показан не полностью - уточните запрос что бы просмотреть больше результатов.",
    "No users or groups found for {search}" : "Не найдено пользователей или групп по запросу {search}",
    "No users found for {search}" : "Не найдено пользователей по запросу {search}",
    "An error occured. Please try again" : "Произошла ошибка. Попробуйте ещё раз",
    "Adding user..." : "Добавляем пользователя...",
    "group" : "группа",
    "remote" : "на другом сервере",
    "Resharing is not allowed" : "Повторное открытие доступа запрещено",
    "Error while retrieving shares" : "Ошибка получения списка общих ресурсов",
    "Unshare" : "Закрыть доступ",
    "notify by email" : "уведомить по эл. почте",
    "can share" : "можно поделиться",
    "can edit" : "можно редактировать",
    "access control" : "контроль доступа",
    "create" : "создать",
    "change" : "изменить",
    "delete" : "удалить",
    "Password protected" : "Защищено паролем",
    "Error unsetting expiration date" : "Ошибка при отмене срока доступа",
    "Error setting expiration date" : "Ошибка при установке срока доступа",
    "Sending ..." : "Отправляется ...",
    "Email sent" : "Письмо отправлено",
    "Warning" : "Предупреждение",
    "This share is password-protected" : "Общий ресурс защищен паролем",
    "The password is wrong. Try again." : "Неверный пароль. Попробуйте еще раз.",
    "Sort by name" : "Сортировать по имени",
    "Sort by date" : "Сортировать по дате",
    "Cancel upload" : "Отменить загрузку",
    "Album information" : "Сведения об альбоме",
    "File list" : "Список файлов",
    "Sorry, this file could not be found." : "К сожалению, файл не найден.",
    "Reasons might be:" : "Причиной может быть:",
    "the wrong file ID was provided" : "предоставлен ошибочный ID файла",
    "the file was removed" : "файл был удален",
    "the file is corrupt" : "файл поврежден",
    "the encryption key is missing" : "отсутствует ключ шифрования",
    "Here is the error message returned by the server: " : "Вот сообщение об ошибке, возвращенное сервером:",
    "For more information, please contact your friendly Nextcloud administrator." : "Для получения более подробной информации, пожалуйста, обратитесь к администратору вашего Nextcloud.",
    "Sorry, but the server could not fulfill your request." : "К сожалению, сервер не смог выполнить ваш запрос.",
    "Possible reasons for the problem:" : "Возможные причины проблемы:",
    "a conflicting app was installed" : "было установлено конфликтующее приложение",
    "a required component is missing or was disconnected" : "необходимый компонент отсутствует или был отключен",
    "the filesystem is not readable" : "файловая система нечитаема",
    "Sorry, this link doesn't seem to work anymore." : "К сожалению, эта ссылка более недоступна.",
    "the item was removed" : "объект был удалён",
    "the link has expired" : "истёк срок действия ссылки",
    "sharing is disabled" : "закрыт общий доступ",
    "For more information, please ask the person who has sent you this link." : "Для получения дополнительной информации, свяжитесь с тем, кто отправил вам эту ссылку.",
    "Add to your Nextcloud" : "Добавить в свой Nextcloud",
    "Picture view" : "Просмотр изображения",
    "Gallery view" : "Галерея"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
